@@ -25,13 +25,15 @@ Extra:
 - [x] add support for change_type maps
 """
 
+from __future__ import annotations
+
 import os
 import re
 import sys
 import typing
 from collections import OrderedDict, defaultdict
 from datetime import date
-from typing import Callable, Dict, Iterable, List, Optional, Tuple, Type
+from typing import Callable, Iterable
 
 from jinja2 import Environment, PackageLoader
 from packaging.version import InvalidVersion, Version
@@ -48,11 +50,11 @@ else:
     VersionProtocol = typing.Any
 
 
-def get_commit_tag(commit: GitCommit, tags: List[GitTag]) -> Optional[GitTag]:
+def get_commit_tag(commit: GitCommit, tags: list[GitTag]) -> GitTag | None:
     return next((tag for tag in tags if tag.rev == commit.rev), None)
 
 
-def get_version(tag: GitTag) -> Optional[Version]:
+def get_version(tag: GitTag) -> Version | None:
     version = None
     try:
         version = Version(tag.name)
@@ -62,7 +64,7 @@ def get_version(tag: GitTag) -> Optional[Version]:
 
 
 def tag_included_in_changelog(
-    tag: GitTag, used_tags: List, merge_prerelease: bool
+    tag: GitTag, used_tags: list, merge_prerelease: bool
 ) -> bool:
     if tag in used_tags:
         return False
@@ -78,19 +80,19 @@ def tag_included_in_changelog(
 
 
 def generate_tree_from_commits(
-    commits: List[GitCommit],
-    tags: List[GitTag],
+    commits: list[GitCommit],
+    tags: list[GitTag],
     commit_parser: str,
     changelog_pattern: str,
-    unreleased_version: Optional[str] = None,
-    change_type_map: Optional[Dict[str, str]] = None,
-    changelog_message_builder_hook: Optional[Callable] = None,
+    unreleased_version: str | None = None,
+    change_type_map: dict[str, str] | None = None,
+    changelog_message_builder_hook: Callable | None = None,
     merge_prerelease: bool = False,
-) -> Iterable[Dict]:
+) -> Iterable[dict]:
     pat = re.compile(changelog_pattern)
     map_pat = re.compile(commit_parser, re.MULTILINE)
     body_map_pat = re.compile(commit_parser, re.MULTILINE | re.DOTALL)
-    current_tag: Optional[GitTag] = None
+    current_tag: GitTag | None = None
 
     # Check if the latest commit is not tagged
     if commits:
@@ -105,8 +107,8 @@ def generate_tree_from_commits(
         current_tag_name = current_tag.name
         current_tag_date = current_tag.date
 
-    changes: Dict = defaultdict(list)
-    used_tags: List = [current_tag]
+    changes: dict = defaultdict(list)
+    used_tags: list = [current_tag]
     for commit in commits:
         commit_tag = get_commit_tag(commit, tags)
 
@@ -130,7 +132,7 @@ def generate_tree_from_commits(
         # Process subject from commit message
         message = map_pat.match(commit.message)
         if message:
-            parsed_message: Dict = message.groupdict()
+            parsed_message: dict = message.groupdict()
             # change_type becomes optional by providing None
             change_type = parsed_message.pop("change_type", None)
 
@@ -146,7 +148,7 @@ def generate_tree_from_commits(
             message_body = body_map_pat.match(body_part)
             if not message_body:
                 continue
-            parsed_message_body: Dict = message_body.groupdict()
+            parsed_message_body: dict = message_body.groupdict()
 
             change_type = parsed_message_body.pop("change_type", None)
             if change_type_map:
@@ -156,7 +158,7 @@ def generate_tree_from_commits(
     yield {"version": current_tag_name, "date": current_tag_date, "changes": changes}
 
 
-def order_changelog_tree(tree: Iterable, change_type_order: List[str]) -> Iterable:
+def order_changelog_tree(tree: Iterable, change_type_order: list[str]) -> Iterable:
     if len(set(change_type_order)) != len(change_type_order):
         raise InvalidConfigurationError(
             f"Change types contain duplicates types ({change_type_order})"
@@ -184,7 +186,7 @@ def render_changelog(tree: Iterable) -> str:
     return changelog
 
 
-def parse_version_from_markdown(value: str) -> Optional[str]:
+def parse_version_from_markdown(value: str) -> str | None:
     if not value.startswith("#"):
         return None
     m = re.search(defaults.version_parser, value)
@@ -193,7 +195,7 @@ def parse_version_from_markdown(value: str) -> Optional[str]:
     return m.groupdict().get("version")
 
 
-def parse_title_type_of_line(value: str) -> Optional[str]:
+def parse_title_type_of_line(value: str) -> str | None:
     md_title_parser = r"^(?P<title>#+)"
     m = re.search(md_title_parser, value)
     if not m:
@@ -201,12 +203,12 @@ def parse_title_type_of_line(value: str) -> Optional[str]:
     return m.groupdict().get("title")
 
 
-def get_metadata(filepath: str) -> Dict:
-    unreleased_start: Optional[int] = None
-    unreleased_end: Optional[int] = None
-    unreleased_title: Optional[str] = None
-    latest_version: Optional[str] = None
-    latest_version_position: Optional[int] = None
+def get_metadata(filepath: str) -> dict:
+    unreleased_start: int | None = None
+    unreleased_end: int | None = None
+    unreleased_title: str | None = None
+    latest_version: str | None = None
+    latest_version_position: int | None = None
     if not os.path.isfile(filepath):
         return {
             "unreleased_start": None,
@@ -219,7 +221,7 @@ def get_metadata(filepath: str) -> Dict:
         for index, line in enumerate(changelog_file):
             line = line.strip().lower()
 
-            unreleased: Optional[str] = None
+            unreleased: str | None = None
             if "unreleased" in line:
                 unreleased = parse_title_type_of_line(line)
             # Try to find beginning and end lines of the unreleased block
@@ -249,7 +251,7 @@ def get_metadata(filepath: str) -> Dict:
     }
 
 
-def incremental_build(new_content: str, lines: List[str], metadata: Dict) -> List[str]:
+def incremental_build(new_content: str, lines: list[str], metadata: dict) -> list[str]:
     """Takes the original lines and updates with new_content.
 
     The metadata governs how to remove the old unreleased section and where to place the
@@ -267,7 +269,7 @@ def incremental_build(new_content: str, lines: List[str], metadata: Dict) -> Lis
     unreleased_end = metadata.get("unreleased_end")
     latest_version_position = metadata.get("latest_version_position")
     skip = False
-    output_lines: List[str] = []
+    output_lines: list[str] = []
     for index, line in enumerate(lines):
         if index == unreleased_start:
             skip = True
@@ -297,8 +299,8 @@ def incremental_build(new_content: str, lines: List[str], metadata: Dict) -> Lis
 
 
 def get_smart_tag_range(
-    tags: List[GitTag], newest: str, oldest: Optional[str] = None
-) -> List[GitTag]:
+    tags: list[GitTag], newest: str, oldest: str | None = None
+) -> list[GitTag]:
     """Smart because it finds the N+1 tag.
 
     This is because we need to find until the next tag
@@ -323,19 +325,19 @@ def get_smart_tag_range(
 
 
 def get_oldest_and_newest_rev(
-    tags: List[GitTag],
+    tags: list[GitTag],
     version: str,
     tag_format: str,
-    version_type_cls: Optional[Type[VersionProtocol]] = None,
-) -> Tuple[Optional[str], Optional[str]]:
+    version_type_cls: type[VersionProtocol] | None = None,
+) -> tuple[str | None, str | None]:
     """Find the tags for the given version.
 
     `version` may come in different formats:
     - `0.1.0..0.4.0`: as a range
     - `0.3.0`: as a single version
     """
-    oldest: Optional[str] = None
-    newest: Optional[str] = None
+    oldest: str | None = None
+    newest: str | None = None
     try:
         oldest, newest = version.split("..")
     except ValueError:
@@ -355,7 +357,7 @@ def get_oldest_and_newest_rev(
     if not tags_range:
         raise NoCommitsFoundError("Could not find a valid revision range.")
 
-    oldest_rev: Optional[str] = tags_range[-1].name
+    oldest_rev: str | None = tags_range[-1].name
     newest_rev = newest_tag
 
     # check if it's the first tag created
