@@ -1,7 +1,9 @@
+from __future__ import annotations
+
 import os.path
 from difflib import SequenceMatcher
 from operator import itemgetter
-from typing import Callable, Dict, List, Optional
+from typing import Callable
 
 from commitizen import bump, changelog, defaults, factory, git, out, version_types
 from commitizen.config import BaseConfig
@@ -14,6 +16,7 @@ from commitizen.exceptions import (
     NotAllowed,
 )
 from commitizen.git import GitTag, smart_open
+from packaging.version import parse
 
 
 class Changelog:
@@ -36,6 +39,13 @@ class Changelog:
             "changelog_incremental"
         )
         self.dry_run = args["dry_run"]
+
+        self.current_version = (
+            args.get("current_version") or self.config.settings.get("version") or ""
+        )
+        self.current_version_instance = (
+            parse(self.current_version) if self.current_version else None
+        )
         self.unreleased_version = args["unreleased_version"]
         self.change_type_map = (
             self.config.settings.get("change_type_map") or self.cz.change_type_map
@@ -56,7 +66,7 @@ class Changelog:
         version_type = self.config.settings.get("version_type")
         self.version_type = version_type and version_types.VERSION_TYPES[version_type]
 
-    def _find_incremental_rev(self, latest_version: str, tags: List[GitTag]) -> str:
+    def _find_incremental_rev(self, latest_version: str, tags: list[GitTag]) -> str:
         """Try to find the 'start_rev'.
 
         We use a similarity approach. We know how to parse the version from the markdown
@@ -83,7 +93,7 @@ class Changelog:
         return start_rev
 
     def write_changelog(
-        self, changelog_out: str, lines: List[str], changelog_meta: Dict
+        self, changelog_out: str, lines: list[str], changelog_meta: dict
     ):
         if not isinstance(self.file_name, str):
             raise NotAllowed(
@@ -92,9 +102,9 @@ class Changelog:
                 f"or the setting `changelog_file` in {self.config.path}"
             )
 
-        changelog_hook: Optional[Callable] = self.cz.changelog_hook
+        changelog_hook: Callable | None = self.cz.changelog_hook
         with smart_open(self.file_name, "w") as changelog_file:
-            partial_changelog: Optional[str] = None
+            partial_changelog: str | None = None
             if self.incremental:
                 new_lines = changelog.incremental_build(
                     changelog_out, lines, changelog_meta
@@ -111,11 +121,11 @@ class Changelog:
         changelog_pattern = self.cz.changelog_pattern
         start_rev = self.start_rev
         unreleased_version = self.unreleased_version
-        changelog_meta: Dict = {}
-        change_type_map: Optional[Dict] = self.change_type_map
-        changelog_message_builder_hook: Optional[
+        changelog_meta: dict = {}
+        change_type_map: dict | None = self.change_type_map
+        changelog_message_builder_hook: None | (
             Callable
-        ] = self.cz.changelog_message_builder_hook
+        ) = self.cz.changelog_message_builder_hook
         merge_prerelease = self.merge_prerelease
 
         if not changelog_pattern or not commit_parser:
@@ -155,7 +165,10 @@ class Changelog:
             )
 
         commits = git.get_commits(start=start_rev, end=end_rev, args="--topo-order")
-        if not commits:
+        if not commits and (
+            self.current_version_instance is None
+            or not self.current_version_instance.is_prerelease
+        ):
             raise NoCommitsFoundError("No commits found")
 
         tree = changelog.generate_tree_from_commits(
